@@ -12,7 +12,7 @@ use Readonly;
 Readonly::Scalar our $EMPTY_STR => q{};
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Record.
 sub record {
@@ -45,6 +45,13 @@ sub report {
 	return wantarray ? @report : $report_scalar;
 }
 
+# Reset records.
+sub reset {
+	my $self = shift;
+	@{$self} = ();
+	return;
+}
+
 # Get state.
 sub state {
 	my $self = shift;
@@ -69,6 +76,7 @@ __END__
  my $m = Memory::Process->new(%params);
  $m->dump;
  $m->record($message, $pid);
+ $m->reset;
  my @report = $m->report;
  my $report = $m->report;
  $m->state;
@@ -99,6 +107,11 @@ __END__
  In array context returns array of report lines.
  First line is title.
 
+=item C<reset()>
+
+ Reset records.
+ Returns undef.
+
 =item C<state()>
 
  Get internal state.
@@ -236,6 +249,6 @@ L<http://skim.cz/>
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
